@@ -1,6 +1,9 @@
 package Dist::Zilla::PluginBundle::SHLOMIF;
+$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000005';
 our $AUTHORITY = 'cpan:SHLOMIF';
-$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000004';
+
+use 5.014;
+
 use Moose;
 # ABSTRACT: Dist::Zilla plugins for me
 
@@ -203,7 +206,6 @@ has _plugins => (
                 MetaJSON
                 MetaProvides::Package
                 MetaResources
-                Metadata
                 ModuleBuild
                 PkgVersion
                 PodCoverageTests
@@ -234,10 +236,6 @@ has plugin_options => (
             'Authority'          => { authority => $self->authority },
         );
 
-        $opts{Metadata} = {
-            dynamic_config => 1,
-        } if $self->dynamic_config;
-
         for my $metaresource (qw(repository.type repository.url repository.web bugtracker.web bugtracker.mailto homepage)) {
             (my $method = $metaresource) =~ s/\./_/g;
             my $value = $self->$method;
@@ -303,7 +301,7 @@ Dist::Zilla::PluginBundle::SHLOMIF - Dist::Zilla plugins for me
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 SYNOPSIS
 
